@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,26 +26,29 @@
 
 namespace Gravatar {
 class GravatarCachePrivate;
-class GRAVATAR_EXPORT GravatarCache : public QObject
+class Hash;
+
+class GRAVATAR_EXPORT GravatarCache
 {
-    Q_OBJECT
 public:
     static GravatarCache *self();
 
     GravatarCache();
     ~GravatarCache();
 
-    void saveGravatarPixmap(const QString &hashStr, const QPixmap &pixmap);
+    void saveGravatarPixmap(const Hash &hash, const QPixmap &pixmap);
+    void saveMissingGravatar(const Hash &hash);
 
-    QPixmap loadGravatarPixmap(const QString &hashStr, bool &gravatarStored);
+    Q_REQUIRED_RESULT QPixmap loadGravatarPixmap(const Hash &hash, bool &gravatarStored);
 
-    int maximumSize() const;
+    Q_REQUIRED_RESULT int maximumSize() const;
     void setMaximumSize(int maximumSize);
 
     void clear();
     void clearAllCache();
 
 private:
+    Q_DISABLE_COPY(GravatarCache)
     GravatarCachePrivate *const d;
 };
 }
